def node_function_1(data):
    """An example function that returns the input data unchanged."""
    print("This is from Node 1")
    return data


def node_function_2(data):
    """An example function that returns the input data unchanged."""
    print("This is from Node 2")
    return data
